@@ -36,6 +36,11 @@ $Authors: Hannes Roest$
 """
 
 import numpy
+import os
+import csv
+import math
+import random
+from numpy import median, absolute
 from msproteomicstoolslib.algorithms.shared.bounds import lower_bound, upper_bound
 
 def get_smooting_operator(use_scikit=False, use_linear=False, use_external_r = False, tmpdir=None):
@@ -76,6 +81,8 @@ def getSmoothingObj(smoother, topN=5, max_rt_diff=30, min_rt_diff=0.1, removeOut
         return UnivarSplineNoCV()
     elif smoother == "CVSpline":
         return UnivarSplineCV()
+    elif smoother == "Earth":
+        return SmoothingEarth()
     elif smoother == "WeightedNearestNeighbour":
         return WeightedNearestNeighbour(topN, max_rt_diff, min_rt_diff, removeOutliers)
     elif smoother == "SmoothLLDMedian":
@@ -87,33 +94,36 @@ def getSmoothingObj(smoother, topN=5, max_rt_diff=30, min_rt_diff=0.1, removeOut
 
 class SmoothingR:
     """Class to smooth data using the smooth.spline function from R
+    
+    This is equivalent to the following code::
 
-     data1 = c(5,7,8,9,10,15,7.1,6)
-     data2 = c(4,7,9,11,11,14,7.1,6.5)
-     data1 = sort(data1)
-     data2 = sort(data2)
-     smooth.model = smooth.spline(data1,data2,cv=T)
-     data2_pred = predict(smooth.model,data2)$y 
-     [1]  2.342662  6.615797  7.292613  7.441842 10.489440 11.858406 11.858406
-     [8] 13.482255
-     plot(data1, data2)
-     lines(data1, data2_pred, col="blue")
+         data1 = c(5,7,8,9,10,15,7.1,6)
+         data2 = c(4,7,9,11,11,14,7.1,6.5)
+         data1 = sort(data1)
+         data2 = sort(data2)
+         smooth.model = smooth.spline(data1,data2,cv=T)
+         data2_pred = predict(smooth.model,data2)$y 
+         [1]  2.342662  6.615797  7.292613  7.441842 10.489440 11.858406 11.858406
+         [8] 13.482255
+         plot(data1, data2)
+         lines(data1, data2_pred, col="blue")
 
 
-    # In python ...
-    import rpy2.robjects as robjects
-    # uses python-rpy2
-    data1 = [5,7,8,9,10,15,7.1,6]
-    data2 = [4,7,9,11,11,14,7.1,6.5]
-    rdata1 = robjects.FloatVector(data1)
-    rdata2 = robjects.FloatVector(data2)
-    spline = robjects.r["smooth.spline"]
-    sm = spline(data1,data2,cv=T)
-    predict = robjects.r["predict"]
-    predicted_data = predict(sm, rdata2)
-    numpy.array(predicted_data[1])
-    array([  2.34266247,   7.2926131 ,  10.48943975,  11.85840597,
-            11.85840597,  13.48225519,   7.44184246,   6.61579704])
+    Doing the same thing in Python ::
+
+        import rpy2.robjects as robjects
+        # uses python-rpy2
+        data1 = [5,7,8,9,10,15,7.1,6]
+        data2 = [4,7,9,11,11,14,7.1,6.5]
+        rdata1 = robjects.FloatVector(data1)
+        rdata2 = robjects.FloatVector(data2)
+        spline = robjects.r["smooth.spline"]
+        sm = spline(data1,data2,cv=T)
+        predict = robjects.r["predict"]
+        predicted_data = predict(sm, rdata2)
+        numpy.array(predicted_data[1])
+        array([  2.34266247,   7.2926131 ,  10.48943975,  11.85840597,
+                11.85840597,  13.48225519,   7.44184246,   6.61579704])
 
     """
 
@@ -160,7 +170,6 @@ class SmoothingRExtern:
         self.internal_interpolation.initialize(arr[:,0], arr[:,1])
 
     def predict_R_(self, data1, data2, predict_data, TMPDIR):
-        import random
         fname = TMPDIR + "/datafile_feature_align_%s" % int(random.random() * 100000)
         fname_pred = TMPDIR + "/datafile_feature_align_%s" % int(random.random() * 100000)
         fname_out = TMPDIR + "/datafile_feature_align_%s" % int(random.random() * 100000)
@@ -196,11 +205,9 @@ class SmoothingRExtern:
         fh.close()
 
         # Execute command
-        import os
         cmd = "R --slave --args %s %s %s < %s" % (fname, fname_pred, fname_out, Rscript) 
         os.system(cmd)
 
-        import csv
         try:
             r = csv.reader(open(fname_out), delimiter="\t")
             r.next()
@@ -368,8 +375,12 @@ class LowessSmoothingPy:
         pass
 
     def initialize(self, data1, data2):
-        from Bio.Statistics.lowess import lowess
-        import math
+        try:
+            from Bio.Statistics.lowess import lowess
+        except ImportError:
+            print "==================================="
+            print "Cannot import the module lowess from Biopython, \nplease install 'biopython' from https://pypi.python.org/pypi/biopython"
+            print "==================================="
 
         old_settings = numpy.seterr(all='ignore')
         result = lowess(numpy.array(data1), numpy.array(data2), f=0.1, iter=10)
@@ -417,7 +428,6 @@ class UnivarSplineCV:
 
     def initialize(self, data1, data2, frac_training_data = 0.75, max_iter = 100, s_iter_decrease = 0.75, verb=False):
         from scipy.interpolate import UnivariateSpline
-        import random
 
         if verb: 
             print " --------------------" 
@@ -496,6 +506,31 @@ class UnivarSplineCV:
     def predict(self, xhat):
         return list(self.sp(xhat))
 
+class SmoothingEarth:
+    """Class for MARS type smoothing based on pyearth
+
+    Get it at https://github.com/jcrudy/py-earth/
+    """
+
+    def __init__(self):
+        pass
+
+    def initialize(self, data1, data2):
+        try:
+            import pyearth
+        except ImportError:
+            print "==================================="
+            print "Cannot import pyearth, \nplease install it from https://github.com/jcrudy/py-earth/"
+            print "==================================="
+
+        self.model = pyearth.Earth()
+        X = numpy.array(data1)
+        Y = numpy.array(data2)
+        self.model.fit(X, Y)
+
+    def predict(self, xhat):
+        return list(self.model.predict(xhat))
+
 class SmoothingLinear:
     """Class for linear transformation
     """
@@ -538,6 +573,16 @@ class SmoothingInterpolation:
         except ValueError:
             # outside bound, use linear
             return self.linear_sm.predict(xhat)
+
+        # If the input is a list, we need to check every value in the list
+        # -> fix those that are "NA"
+        if any( [math.isnan(pp) for pp in predicted_result] ):
+            
+            for i, (qq, pp) in enumerate(zip(xhat, predicted_result)):
+                if (math.isnan(pp)):
+                    predicted_result[ i ] = self.linear_sm.predict([ qq ])[0]
+
+
         return list(predicted_result)
 
 class LocalKernel:
@@ -650,8 +695,6 @@ class SmoothLLDMedian(LocalKernel):
 
     def predict(self, xhat):
 
-        from numpy import median, absolute
-
         def mad(data, axis=None):
             """Median absolute deviation (MAD) is a robust estimator of variation.
 
